==> dde-session-shell_5.5.34.tar.xz: BUILD/translations/dde-session-shell_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>面容</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>验证成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>验证失败，您还可以尝试%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>验证失败，您还可以尝试1次</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>请验证人脸ID</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>人脸ID已锁定，请输入密码</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>设备不可用！</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>请验证指纹</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>验证成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>验证失败，您还可以尝试%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>验证失败，您还可以尝试1次</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>指纹已锁定，请输入密码</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>虹膜</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>验证成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>验证失败，您还可以尝试%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>验证失败，您还可以尝试1次</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>请验证虹膜ID</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>虹膜ID已锁定，请输入密码</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>验证成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>验证失败，您还可以尝试%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>验证失败，您还可以尝试1次</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>密码错误</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>请输入密码</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>请1分钟后再试</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>请%n分钟后再试</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>重置密码</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>忘记密码？</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>请1分钟后再试</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>请%n分钟后再试</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>重置密码</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>忘记密码？</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>验证成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>验证失败，您还可以尝试%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>验证失败，您还可以尝试1次</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PIN错误</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>需要使用UKEY认证</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>识别到UKEY，需要输入PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>请%n分钟后再试</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>请1分钟后再试</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>请%n分钟后再试</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>帐户</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>密码将于%n天后过期，请及时修改密码</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>密码已过期，请修改</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>帐户错误</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>密码错误</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>锁屏</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>锁屏失败</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>指纹密码验证超时，请手动输入密码</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>指纹解锁失败</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>此电脑还有以上帐户在登录，关闭电脑会导致其数据丢失，是否要关闭此电脑？</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>此电脑还有以上帐户在登录，重启电脑会导致其数据丢失，是否要重启此电脑？</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>您已开启高级别等级保护，无法切换Wayland模式，请于“安全中心”关闭高级别等级保护后再试</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待机</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>锁定</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>注销</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>切换用户</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>切换系统</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>启动系统监视器</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>以上程序阻止关机，强制关机可能会导致其数据丢失。</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>您可以点击“取消”然后关闭这些程序。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>以上程序阻止重启，强制重启可能会导致其数据丢失。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>以上程序阻止待机，强制待机可能会导致其数据丢失。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>以上程序阻止休眠，强制休眠可能会导致其数据丢失。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>以上程序阻止注销，强制注销可能会导致其数据丢失。</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待机</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>注销</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>您确定要关机吗？</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>您确定要重启吗？</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>您确定要注销吗？</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>开启</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>关闭</translation>
    </message>
</context>
</TS>

==> dde-session-shell_6.0.21.tar.xz: BUILD/translations/dde-session-shell_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>面容</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>验证成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>验证失败，您还可以尝试%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>验证失败，您还可以尝试1次</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>请验证人脸ID</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>人脸ID已锁定，请输入密码</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>设备不可用！</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>请验证指纹</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>验证成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>验证失败，您还可以尝试%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>验证失败，您还可以尝试1次</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>指纹已锁定，请输入密码</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>虹膜</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>验证成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>验证失败，您还可以尝试%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>验证失败，您还可以尝试1次</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>请验证虹膜ID</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>虹膜ID已锁定，请输入密码</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>验证成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>验证失败，您还可以尝试%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>验证失败，您还可以尝试1次</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>密码错误</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>请输入密码</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>请1分钟后再试</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>请%n分钟后再试</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>重置密码</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>忘记密码？</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>请1分钟后再试</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>请%n分钟后再试</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>重置密码</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>忘记密码？</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>验证成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>验证失败，您还可以尝试%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>验证失败，您还可以尝试1次</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PIN错误</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>需要使用UKEY认证</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>识别到UKEY，需要输入PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>请%n分钟后再试</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>请1分钟后再试</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>请%n分钟后再试</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>帐户</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>密码将于%n天后过期，请及时修改密码</numerusform></translation>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it.</source>
        <translation>您的密码已过期，请联系管理员修改密码</translation>
    </message>
    <message>
        <source>Your password has expired. Please change it.</source>
        <translation>密码已过期，请修改</translation>
    </message>
</context>
<context>
    <name>ChangePasswordWidget</name>
    <message>
        <source>Your password has expired. Please change it and log in again.</source>
        <translation>您的密码已过期，请修改密码后重新登录</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保 存</translation>
    </message>
    <message>
        <source>Old password</source>
        <translation>旧密码</translation>
    </message>
    <message>
        <source>New password</source>
        <translation>新密码</translation>
    </message>
    <message>
        <source>Repeat new password</source>
        <translation>重复新密码</translation>
    </message>
    <message>
        <source>Password hint (Optional)</source>
        <translation>密码提示（选填）</translation>
    </message>
    <message>
        <source>Passwords do not match</source>
        <translation>密码不一致</translation>
    </message>
    <message>
        <source>The hint is visible to all users. Do not include the password here.</source>
        <translation>密码提示对所有人可见，切勿包含具体密码信息</translation>
    </message>
    <message>
        <source>New password should differ from the current one</source>
        <translation>新密码和旧密码不能相同</translation>
    </message>
    <message>
        <source>Password changed</source>
        <translation>密码修改成功</translation>
    </message>
    <message>
        <source>Wrong password</source>
        <translation>密码错误</translation>
    </message>
</context>
<context>
    <name>ControlWidget</name>
    <message>
        <source>Desktop Environment and Display Protocol</source>
        <translation>桌面环境与显示协议</translation>
    </message>
    <message>
        <source>Keyboard Layout</source>
        <translation>键盘布局</translation>
    </message>
    <message>
        <source>Switch User</source>
        <translation>切换用户</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>电源</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>帐户错误</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>密码错误</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>锁屏</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>锁屏失败</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>指纹密码验证超时，请手动输入密码</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>指纹解锁失败</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>此电脑还有以上帐户在登录，关闭电脑会导致其数据丢失，是否要关闭此电脑？</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>此电脑还有以上帐户在登录，重启电脑会导致其数据丢失，是否要重启此电脑？</translation>
    </message>
</context>
<context>
    <name>PasswordLevelWidget</name>
    <message>
        <source>Weak</source>
        <translation>强度低</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>强度中</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>强度高</translation>
    </message>
</context>
<context>
    <name>PwqualityManager</name>
    <message>
        <source>Password cannot be empty</source>
        <translation>密码不能为空</translation>
    </message>
    <message>
        <source>Password must have at least %1 characters</source>
        <translation>密码长度不能少于%1个字符</translation>
    </message>
    <message>
        <source>Password must be no more than %1 characters</source>
        <translation>密码长度不能超过%1个字符</translation>
    </message>
    <message>
        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>密码只能由英文（区分大小写）、数字或特殊符号（~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/）组成</translation>
    </message>
    <message>
        <source>No more than %1 palindrome characters please</source>
        <translation>回文字符长度不超过%1位</translation>
    </message>
    <message>
        <source>No more than %1 monotonic characters please</source>
        <translation>单调性字符不超过%1位</translation>
    </message>
    <message>
        <source>No more than %1 repeating characters please</source>
        <translation>重复字符不超过%1位</translation>
    </message>
    <message>
        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>密码必须由大写字母、小写字母、数字、符号（~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/）三种类型组成</translation>
    </message>
    <message>
        <source>Password must not contain more than 4 palindrome characters</source>
        <translation>密码不得含有连续4个以上的回文字符</translation>
    </message>
    <message>
        <source>Do not use common words and combinations as password</source>
        <translation>密码不能是常见单词及组合</translation>
    </message>
    <message>
        <source>Create a strong password please</source>
        <translation>密码过于简单，请增加密码复杂度</translation>
    </message>
    <message>
        <source>It does not meet password rules</source>
        <translation>密码不符合安全要求</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待机</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>锁定</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>注销</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>切换系统</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>切换用户</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>启动系统监视器</translation>
    </message>
</context>
<context>
    <name>UserListPopupWidget</name>
    <message>
        <source>Standard User</source>
        <translation>标准用户</translation>
    </message>
    <message>
        <source>Administrator</source>
        <translation>管理员</translation>
    </message>
    <message>
        <source>Other Users</source>
        <translation>其他用户</translation>
    </message>
</context>
<context>
    <name>VirtualKeyboardModule</name>
    <message>
        <source>Onboard</source>
        <translation>屏幕键盘</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>以上程序阻止关机，强制关机可能会导致其数据丢失。</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>您可以点击“取消”然后关闭这些程序。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>以上程序阻止重启，强制重启可能会导致其数据丢失。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>以上程序阻止待机，强制待机可能会导致其数据丢失。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>以上程序阻止休眠，强制休眠可能会导致其数据丢失。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>以上程序阻止注销，强制注销可能会导致其数据丢失。</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待机</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>注销</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>您确定要关机吗？</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>您确定要重启吗？</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>您确定要注销吗？</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>开启</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>关闭</translation>
    </message>
</context>
</TS>
